==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/InAppMessage.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class InAppMessage(
    content: Option[Iterable[zio.aws.pinpoint.model.InAppMessageContent]] =
      None,
    customConfig: Option[Map[__string, __string]] = None,
    layout: Option[zio.aws.pinpoint.model.Layout] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.InAppMessage = {
    import InAppMessage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.InAppMessage
      .builder()
      .optionallyWith(
        content.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.content)
      .optionallyWith(
        customConfig.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> (__string
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.customConfig)
      .optionallyWith(layout.map(value => value.unwrap))(_.layout)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.InAppMessage.ReadOnly =
    zio.aws.pinpoint.model.InAppMessage.wrap(buildAwsValue())
}
object InAppMessage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.InAppMessage =
      zio.aws.pinpoint.model.InAppMessage(
        content.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        customConfig.map(value => value),
        layout.map(value => value)
      )
    def content
        : Option[List[zio.aws.pinpoint.model.InAppMessageContent.ReadOnly]]
    def customConfig: Option[Map[__string, __string]]
    def layout: Option[zio.aws.pinpoint.model.Layout]
    def getContent: ZIO[Any, AwsError, List[
      zio.aws.pinpoint.model.InAppMessageContent.ReadOnly
    ]] = AwsError.unwrapOptionField("content", content)
    def getCustomConfig: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("customConfig", customConfig)
    def getLayout: ZIO[Any, AwsError, zio.aws.pinpoint.model.Layout] =
      AwsError.unwrapOptionField("layout", layout)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ) extends zio.aws.pinpoint.model.InAppMessage.ReadOnly {
    override val content
        : Option[List[zio.aws.pinpoint.model.InAppMessageContent.ReadOnly]] =
      scala
        .Option(impl.content())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.pinpoint.model.InAppMessageContent.wrap(item)
          }.toList
        )
    override val customConfig: Option[Map[__string, __string]] = scala
      .Option(impl.customConfig())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.pinpoint.model.primitives.__string(
              key
            ) -> zio.aws.pinpoint.model.primitives.__string(value)
          })
          .toMap
      )
    override val layout: Option[zio.aws.pinpoint.model.Layout] = scala
      .Option(impl.layout())
      .map(value => zio.aws.pinpoint.model.Layout.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ): zio.aws.pinpoint.model.InAppMessage.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/InAppMessage.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class InAppMessage(
    content: Optional[Iterable[zio.aws.pinpoint.model.InAppMessageContent]] =
      Optional.Absent,
    customConfig: Optional[Map[__string, __string]] = Optional.Absent,
    layout: Optional[zio.aws.pinpoint.model.Layout] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.InAppMessage = {
    import InAppMessage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.InAppMessage
      .builder()
      .optionallyWith(
        content.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.content)
      .optionallyWith(
        customConfig.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.customConfig)
      .optionallyWith(layout.map(value => value.unwrap))(_.layout)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.InAppMessage.ReadOnly =
    zio.aws.pinpoint.model.InAppMessage.wrap(buildAwsValue())
}
object InAppMessage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.InAppMessage =
      zio.aws.pinpoint.model.InAppMessage(
        content.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        customConfig.map(value => value),
        layout.map(value => value)
      )
    def content
        : Optional[List[zio.aws.pinpoint.model.InAppMessageContent.ReadOnly]]
    def customConfig: Optional[Map[__string, __string]]
    def layout: Optional[zio.aws.pinpoint.model.Layout]
    def getContent: ZIO[Any, AwsError, List[
      zio.aws.pinpoint.model.InAppMessageContent.ReadOnly
    ]] = AwsError.unwrapOptionField("content", content)
    def getCustomConfig: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("customConfig", customConfig)
    def getLayout: ZIO[Any, AwsError, zio.aws.pinpoint.model.Layout] =
      AwsError.unwrapOptionField("layout", layout)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ) extends zio.aws.pinpoint.model.InAppMessage.ReadOnly {
    override val content
        : Optional[List[zio.aws.pinpoint.model.InAppMessageContent.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.content())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.pinpoint.model.InAppMessageContent.wrap(item)
          }.toList
        )
    override val customConfig: Optional[Map[__string, __string]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customConfig())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: __string) -> (value: __string)
            })
            .toMap
        )
    override val layout: Optional[zio.aws.pinpoint.model.Layout] =
      zio.aws.core.internal
        .optionalFromNullable(impl.layout())
        .map(value => zio.aws.pinpoint.model.Layout.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.InAppMessage
  ): zio.aws.pinpoint.model.InAppMessage.ReadOnly = new Wrapper(impl)
}
